/* General Styles */
body {
    background-color: #1e1e1e;
    color: #ffffff;
    font-family: "Roboto Mono", monospace;
    overflow: hidden; /* No body scrolling */
    height: fit-content;
}

.container-fluid {
    padding: 20px;
    background-color: #2a2a2a;
    border-radius: 8px;
    box-shadow: 0 0 10px rgba(0,0,0,0.8);
    width: 90%;
    margin-top: 10px;
}

#header {
    background-color: #2a2a2a;
    padding: 8px 20px;
    margin: 0;
    display: block;
    box-shadow: 0 0 10px rgba(0,0,0,0.8);
    width: 100vw;
}

#scan-container {
    width: 100vw;
    height: 100%;
    overflow-y: auto;
}

.scroll-container {
    width: 100vw;
    height: 100vh;
    overflow-y: auto;
}


h1, h2, h3 {
    font-weight: 600;
    color: #e0e0e0;
}

hr {
    border-color: #444;
    margin: 20px 0;
}

.title span {
    color: #007bff;
}

.overview-container {
    display: flex;
    justify-content: space-around;
    width: 100vw;
    height: 100px;
}

/* Layout Styles */
details {
    background-color: #333;
    border: 1px solid #555;
    padding: 10px;
    border-radius: 5px;
}

#scan-results {
    margin-top: 20px;
}

#overview-frame, #ip-table-frame {
    width: 100%;
}

#overview-frame {
    height: 120px;
}


#scan-form {
    width: 500px;
    margin: 0;
}
#scan-form label {
    margin-bottom: 0;
}
#scan-form input {
    z-index: 2;
    transition: all .2s ease-in-out;
}
.label-container {
    display: flex;
    justify-content: space-between;
}
#subnet-info {
    margin-right: 5px;
    font-size: .8em;
    padding: 2px 5px;
    background-color: #333;
    border: 1px solid #444;
    border-bottom: none;
    border-radius: 5px 5px 0 0;
    color: #aaa;
    transition: all .2s ease-in-out;
    height: 25px;
}
#scan-form.error #subnet-info,
#scan-form.error input
 {
    color: #a66;
    border-color: #722;
    outline: 0 none;
}
#scan-form.error input:focus {
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.075) inset, 0 0 8px rgba(200, 85, 85, 0.6);
}


/* Card Styles */
.card {
    background-color: #282828;
    border-color: #444;
}

.card-header {
    background-color: rgba(0, 0, 0, 0.5);
    color: #ffffff;
    border-bottom: 1px solid #444;
}


/* Form / Input Styles */
form {
    display: flex;
    justify-content: space-between;
    align-items: center;
    gap: 15px;
    margin-bottom: 20px;
}

.form-group {
    flex-grow: 1;
    display: flex;
    flex-direction: column;
    margin-bottom: 15px;
}

label {
    color: #ffffff;
    font-weight: 500;
    margin-bottom: 5px;
}

input[type="text"], input[type="number"], select, .form-control {
    background-color: #232323;
    border: 1px solid #444;
    color: #e0e0e0;
    padding: 8px 10px;
    font-size: 1rem;
    border-radius: 5px;
}

input[type="text"]:focus, select:focus, .form-control:focus {
    background-color: #1e1e1e;
    color: #ffffff;
    border-color: #4a90e2;
    outline: none;
}

input::placeholder {
    color: #bbb !important;
}

button {
    margin-left: 15px;
    padding: 10px 20px;
}
.div-hide {
    display: none !important;
}

/* Button Styling */
.btn-primary, button.btn-primary {
    background-color: #007bff;
    border: none;
    padding: 10px 20px;
    color: #fff;
    font-size: 1rem;
    cursor: pointer;
    border-radius: 5px;
    transition: background-color 0.2s ease;
}

.btn-primary:hover {
    background-color: #0056b3;
}
input[type="range"] {
    -webkit-appearance: none;
    width: 100%;
    height: 8px;
    background-color: #444;
    outline: none;
    border-radius: 5px;
    margin: 5px 0;
}

input[type="range"]::-webkit-slider-thumb,
input[type="range"]::-moz-range-thumb {
    -webkit-appearance: none;
    appearance: none;
    width: 16px;
    height: 16px;
    border-radius: 50%;
    background: #007bff;
    cursor: pointer;
}
#parallelism-value span {
    color: #fa7a7a;
    font-weight: 500;
}
.port-list-wrapper {
    position: relative;
    display: inline-block;
    width: 100%;
}

.port-list {
    position: relative;
    background-color: #232323;
    border: 1px solid #555;
    color: #e0e0e0;
    padding: 10px;
    cursor: pointer;
    width: 100%;
    user-select: none;
    appearance: none;  /* Hide default arrow */
}

.port-list:focus {
    border-color: #4a90e2;
    outline: none;
}

.port-list-wrapper::after {
    content: '▼';
    position: absolute;
    top: 14px;
    right: 10px;
    pointer-events: none;
    color: #e0e0e0;
}

.port-list-dropdown {
    display: none;
    position: absolute;
    background-color: #232323;
    border: 1px solid #555;
    width: 100%;
    max-height: 200px;
    overflow-y: auto;
    z-index: 10;
}

.port-list-dropdown.open {
    display: block;
}

.port-list-dropdown div {
    padding: 10px;
    color: #e0e0e0;
    cursor: pointer;
}

.port-list-dropdown div:hover {
    background-color: #4a90e2;
    color: white;
}


/* Table Styles */
.table-container {
    width: 100vw;
    margin: auto;
}

.table {
    color: #e0e0e0;
    width: 100%;
}

.table th, .table td {
    background-color: #282828;
    border-color: #444;
    color: #e0e0e0;
}

.table thead th {
    background-color: #333;
}

.table-striped tbody tr:nth-of-type(odd) td {
    background-color: #232323;
}

.table-striped tbody tr:nth-of-type(even) td {
    background-color: #2b2b2b;
}

.table tbody tr:hover {
    background-color: #3a3a3a;
}


/* Badge Styles */
.badge-warning {
    background-color: #ffcc00;
    color: #000;
}

.badge-success, .badge-info, .badge-secondary {
    color: #ffffff;
}

.badge-success {
    background-color: #28a745;
}

.badge-info {
    background-color: #17a2b8;
}

.badge-secondary {
    background-color: #6c757d;
}


/* Protocol Open Button Styles */
.colorful-buttons a:nth-of-type(4n+1) {
    background-color: #007bff;
    border-color: #0064cf;
}

.colorful-buttons a:nth-of-type(4n+1):hover {
    background-color: #0056b3;
    border-color: #004b9e;
}

.colorful-buttons a:nth-of-type(4n+2) {
    background-color: #27a946;
    border-color: #1e7e34;
}

.colorful-buttons a:nth-of-type(4n+2):hover {
    background-color: #1f7d35;
    border-color: #1a6e2e;
}

.colorful-buttons a:nth-of-type(4n+3) {
    background-color: #bf9a06;
    border-color: #8b7002;
}

.colorful-buttons a:nth-of-type(4n+3):hover {
    background-color: #a47f05;
    border-color: #7a6a03;
}

.colorful-buttons a:nth-of-type(4n+4) {
    background-color: #dc3545;
    border-color: #dc3545;
}

.colorful-buttons a:nth-of-type(4n+4):hover {
    background-color: #c82333;
    border-color: #bd2130;
}


/* Transitions */
input, select, button, details {
    transition: all 0.3s ease-in-out;
}

/* Scrollbar styling */
::-webkit-scrollbar {
    width: 12px;  /* Width of the scrollbar */
}

::-webkit-scrollbar-track {
    background-color: #232323; /* Background of the scrollbar track */
    border-radius: 10px;
}

::-webkit-scrollbar-thumb {
    background-color: #444; /* Darker thumb for the scrollbar */
    border-radius: 10px;
    border: 3px solid #232323; /* Adds padding between the thumb and track */
}

.error-container {
    height: 300px;
    overflow-y: scroll;
    margin: 10px;
    padding: 5px;
    background-color: #7776;
}

/* For Firefox */
html {
    scrollbar-width: thin;
    scrollbar-color: #444 #232323;
}
